==> org-lsst-sal-cccamera-2.5.0-sources.jar: org/lsst/sal/cccamera/event/Fcs_LinearEncoder_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Fcs_LinearEncoder_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double linearposition_warnHi;

  private final double linearposition_warnLo;

  private final double linearposition_limitHi;

  private final double linearposition_limitLo;

  public Fcs_LinearEncoder_LimitsConfigurationEvent(int priority, String version,
      double linearposition_warnHi, double linearposition_warnLo, double linearposition_limitHi,
      double linearposition_limitLo) {
    super (priority);
    this.version = version;
    this.linearposition_warnHi = linearposition_warnHi;
    this.linearposition_warnLo = linearposition_warnLo;
    this.linearposition_limitHi = linearposition_limitHi;
    this.linearposition_limitLo = linearposition_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getLinearposition_warnHi() {
    return linearposition_warnHi;
  }

  public double getLinearposition_warnLo() {
    return linearposition_warnLo;
  }

  public double getLinearposition_limitHi() {
    return linearposition_limitHi;
  }

  public double getLinearposition_limitLo() {
    return linearposition_limitLo;
  }

  @Override
  public String toString() {
    return "Fcs_LinearEncoder_LimitsConfigurationEvent{" + "version=" + version +
        ", linearposition_warnHi=" + linearposition_warnHi +
        ", linearposition_warnLo=" + linearposition_warnLo +
        ", linearposition_limitHi=" + linearposition_limitHi +
        ", linearposition_limitLo=" + linearposition_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double linearposition_warnHi;

    private double linearposition_warnLo;

    private double linearposition_limitHi;

    private double linearposition_limitLo;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder linearposition_warnHi(double linearposition_warnHi) {
      this.linearposition_warnHi = linearposition_warnHi;
      return this;
    }

    public Builder linearposition_warnLo(double linearposition_warnLo) {
      this.linearposition_warnLo = linearposition_warnLo;
      return this;
    }

    public Builder linearposition_limitHi(double linearposition_limitHi) {
      this.linearposition_limitHi = linearposition_limitHi;
      return this;
    }

    public Builder linearposition_limitLo(double linearposition_limitLo) {
      this.linearposition_limitLo = linearposition_limitLo;
      return this;
    }

    public Fcs_LinearEncoder_LimitsConfigurationEvent build() {
      return new Fcs_LinearEncoder_LimitsConfigurationEvent(priority, version, linearposition_warnHi, linearposition_warnLo, linearposition_limitHi, linearposition_limitLo);
    }
  }
}

==> org-lsst-sal-cccamera-2.5.5-sources.jar: org/lsst/sal/cccamera/event/Fcs_LinearEncoder_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Fcs_LinearEncoder_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double linearposition_warnHi;

  private final double linearposition_warnLo;

  private final double linearposition_limitHi;

  private final double linearposition_limitLo;

  public Fcs_LinearEncoder_LimitsConfigurationEvent(String version, double linearposition_warnHi,
      double linearposition_warnLo, double linearposition_limitHi, double linearposition_limitLo) {
    this.version = version;
    this.linearposition_warnHi = linearposition_warnHi;
    this.linearposition_warnLo = linearposition_warnLo;
    this.linearposition_limitHi = linearposition_limitHi;
    this.linearposition_limitLo = linearposition_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getLinearposition_warnHi() {
    return linearposition_warnHi;
  }

  public double getLinearposition_warnLo() {
    return linearposition_warnLo;
  }

  public double getLinearposition_limitHi() {
    return linearposition_limitHi;
  }

  public double getLinearposition_limitLo() {
    return linearposition_limitLo;
  }

  @Override
  public String toString() {
    return "Fcs_LinearEncoder_LimitsConfigurationEvent{" + "version=" + version +
        ", linearposition_warnHi=" + linearposition_warnHi +
        ", linearposition_warnLo=" + linearposition_warnLo +
        ", linearposition_limitHi=" + linearposition_limitHi +
        ", linearposition_limitLo=" + linearposition_limitLo +"}";
  }
}
